@@ -2,11 +2,12 @@
    Copyright 2005 University Corporation for Atmospheric Research/Unidata
     See COPYRIGHT file for conditions of use.
 
-   Test netcdf-4 variables. 
+   Test netcdf-4 variables.
    $Id: tst_vars2.c,v 1.35 2010/01/25 21:01:08 ed Exp $
 */
 
 #include <nc_tests.h>
+#include "err_macros.h"
 #include "netcdf.h"
 
 #define FILE_NAME "tst_vars2.nc"
@@ -14,7 +15,7 @@
 #define DIM1_LEN NC_UNLIMITED
 #define DIM1_NAME "Hoplites_Engaged"
 #define VAR_NAME "Battle_of_Marathon"
-#define LOSSES_NAME "Miltiades_Losses"   
+#define LOSSES_NAME "Miltiades_Losses"
 
 #define MAX_CNUM 4
 
@@ -35,7 +36,7 @@ main(int argc, char **argv)
    for (cnum = 0; cnum < MAX_CNUM; cnum++)
    {
       int cmode = 0;
-      
+
       switch(cnum)
       {
          case 0:
@@ -66,7 +67,7 @@ main(int argc, char **argv)
          if (nc_def_var(ncid, VAR_NAME, NC_BYTE, 0, NULL, &varid)) ERR;
          if (nc_enddef(ncid)) ERR;
          if (nc_redef(ncid)) ERR;
-         if (nc_put_att_schar(ncid, varid, _FillValue, NC_BYTE, 1, &fill_value)) ERR;              
+         if (nc_put_att_schar(ncid, varid, _FillValue, NC_BYTE, 1, &fill_value)) ERR;
          if (nc_close(ncid)) ERR;
 
          /* Open the file and check. */
@@ -95,7 +96,7 @@ main(int argc, char **argv)
          if (nc_def_var(ncid, VAR_NAME, NC_BYTE, NUM_DIMS, dimids, &varid)) ERR;
          if (nc_enddef(ncid)) ERR;
          if (nc_redef(ncid)) ERR;
-         if (nc_put_att_schar(ncid, varid, _FillValue, NC_BYTE, 1, &fill_value)) ERR;            
+         if (nc_put_att_schar(ncid, varid, _FillValue, NC_BYTE, 1, &fill_value)) ERR;
          if (nc_enddef(ncid)) ERR;
 
          /* Write the second record. */
@@ -113,7 +114,7 @@ main(int argc, char **argv)
          start[0] = 1;
          if (nc_get_vara_schar(ncid, varid, start, count, &data_in)) ERR;
          if (data_in != data) ERR;
-      
+
          /* Close up. */
          if (nc_close(ncid)) ERR;
 
@@ -142,7 +143,7 @@ main(int argc, char **argv)
          start[0] = 1;
          if (nc_get_vara_schar(ncid, varid, start, count, &data_in)) ERR;
          if (data_in != data) ERR;
-      
+
          if (nc_close(ncid)) ERR;
       }
 
@@ -158,7 +159,7 @@ main(int argc, char **argv)
          if (nc_def_dim(ncid, DIM1_NAME, DIM1_LEN, &dimids[0])) ERR;
          if (nc_def_var(ncid, VAR_NAME, NC_BYTE, NUM_DIMS, dimids, &varid)) ERR;
          if (nc_put_att_int(ncid, varid, LOSSES_NAME, NC_INT, 1, &losses_value)) ERR;
-         if (nc_put_att_schar(ncid, varid, _FillValue, NC_BYTE, 1, &fill_value)) ERR;            
+         if (nc_put_att_schar(ncid, varid, _FillValue, NC_BYTE, 1, &fill_value)) ERR;
          if (nc_close(ncid)) ERR;
 
          /* Open the file and check. */
@@ -182,8 +183,8 @@ main(int argc, char **argv)
       printf("**** testing fill value with three other attributes...");
       {
 #define NUM_LEADERS 3
-         char leader[NUM_LEADERS][NC_MAX_NAME + 1] = {"hair_length_of_strategoi", 
-                                                      "hair_length_of_Miltiades", 
+         char leader[NUM_LEADERS][NC_MAX_NAME + 1] = {"hair_length_of_strategoi",
+                                                      "hair_length_of_Miltiades",
                                                       "hair_length_of_Darius_I"};
          short hair_length[NUM_LEADERS] = {3, 11, 4};
          short short_in;
@@ -196,7 +197,7 @@ main(int argc, char **argv)
          if (nc_def_var(ncid, VAR_NAME, NC_BYTE, NUM_DIMS, dimids, &varid)) ERR;
          for (a = 0; a < NUM_LEADERS; a++)
             if (nc_put_att_short(ncid, varid, leader[a], NC_SHORT, 1, &hair_length[a])) ERR;
-         if (nc_put_att_schar(ncid, varid, _FillValue, NC_BYTE, 1, &fill_value)) ERR;            
+         if (nc_put_att_schar(ncid, varid, _FillValue, NC_BYTE, 1, &fill_value)) ERR;
          if (nc_close(ncid)) ERR;
 
          /* Open the file. */
@@ -257,13 +258,13 @@ main(int argc, char **argv)
          if (nc_def_dim(ncid, DIM_C, DIM_C_LEN, &dimid[2])) ERR;
 
          /* Create var. */
-         if (nc_def_var(ncid, CXX_VAR_NAME, NC_FLOAT, VAR_DIMS, 
+         if (nc_def_var(ncid, CXX_VAR_NAME, NC_FLOAT, VAR_DIMS,
                         var_dimids, &varid)) ERR;
          if (varid) ERR;
 
-         if (nc_put_att(ncid, varid, LONG_NAME, NC_CHAR, strlen(long_name) + 1, 
+         if (nc_put_att(ncid, varid, LONG_NAME, NC_CHAR, strlen(long_name) + 1,
                         long_name)) ERR;
-         if (nc_put_att(ncid, varid, UNITS, NC_CHAR, strlen(UNITS) + 1, 
+         if (nc_put_att(ncid, varid, UNITS, NC_CHAR, strlen(UNITS) + 1,
                         UNITS)) ERR;
 
          /* Check to ensure the atts have their expected attnums. */
@@ -275,7 +276,7 @@ main(int argc, char **argv)
          /* Now add a fill value. This will acutually cause HDF5 to
           * destroy the dataset and recreate it, recreating also the
           * three attributes that are attached to it. */
-         if (nc_put_att(ncid, varid, _FillValue, NC_FLOAT, 
+         if (nc_put_att(ncid, varid, _FillValue, NC_FLOAT,
                         1, &fill_value)) ERR;
 
          /* Check to ensure the atts have their expected attnums. */
@@ -300,7 +301,7 @@ main(int argc, char **argv)
       SUMMARIZE_ERR;
 
 #ifndef NO_NETCDF_2
-      /* The following test is an attempt to recreate a problem occuring
+      /* The following test is an attempt to recreate a problem occurring
          in the cxx tests. The file is created in c++ in nctsts.cpp. */
       printf("**** testing fill value with example from cxx tests in v2 api...");
       {
@@ -441,7 +442,7 @@ main(int argc, char **argv)
       if (nc_close(ncid)) ERR;
    }
 
-   SUMMARIZE_ERR; 
+   SUMMARIZE_ERR;
    printf("**** testing dimension and variable renaming...");
    {
       /* This test contributed by Jeff Whitaker of NOAA - Thanks Jeff! */
@@ -481,7 +482,7 @@ main(int argc, char **argv)
       if (nc_rename_var(ncid, wind_id, "wind")) ERR;
       if (nc_close(ncid)) ERR;
    }
-   SUMMARIZE_ERR; 
+   SUMMARIZE_ERR;
 
 
 /*    printf("*** testing 2D array of NC_CHAR..."); */
@@ -685,7 +686,7 @@ main(int argc, char **argv)
       if (nvars != 1) ERR;
       if (varids_in[0] != 0) ERR;
       if (nc_inq_var(ncid, 0, name_in, &xtype_in, &ndims, dimids_in, &natts)) ERR;
-      if (strcmp(name_in, VAR_NAME5) || xtype_in != NC_INT || ndims != 1 || natts != 0 || 
+      if (strcmp(name_in, VAR_NAME5) || xtype_in != NC_INT || ndims != 1 || natts != 0 ||
 	  dimids_in[0] != 0) ERR;
       if (nc_inq_var_chunking(ncid, 0, &storage_in, chunksize_in)) ERR;
       for (d = 0; d < NDIMS5; d++)
@@ -695,7 +696,7 @@ main(int argc, char **argv)
       for (i = 0; i < DIM5_LEN; i++)
          if (data[i] != data_in[i])
 	    ERR_RET;
-      if (nc_get_var_chunk_cache(ncid, varid, &cache_size_in, &cache_nelems_in, 
+      if (nc_get_var_chunk_cache(ncid, varid, &cache_size_in, &cache_nelems_in,
 				 &cache_preemption_in)) ERR;
       if (cache_size_in != CACHE_SIZE || cache_nelems_in != CACHE_NELEMS ||
 	  cache_preemption_in != CACHE_PREEMPTION) ERR;
@@ -712,7 +713,7 @@ main(int argc, char **argv)
       if (nvars != 1) ERR;
       if (varids_in[0] != 0) ERR;
       if (nc_inq_var(ncid, 0, name_in, &xtype_in, &ndims, dimids_in, &natts)) ERR;
-      if (strcmp(name_in, VAR_NAME5) || xtype_in != NC_INT || ndims != 1 || natts != 0 || 
+      if (strcmp(name_in, VAR_NAME5) || xtype_in != NC_INT || ndims != 1 || natts != 0 ||
 	  dimids_in[0] != 0) ERR;
       if (nc_inq_var_chunking(ncid, 0, &storage_in, chunksize_in)) ERR;
       for (d = 0; d < NDIMS5; d++)
@@ -762,7 +763,7 @@ main(int argc, char **argv)
       if (nvars != 1) ERR;
       if (varids_in[0] != 0) ERR;
       if (nc_inq_var(ncid, 0, name_in, &xtype_in, &ndims, dimids_in, &natts)) ERR;
-      if (strcmp(name_in, VAR_NAME6) || xtype_in != NC_INT || ndims != 1 || natts != 0 || 
+      if (strcmp(name_in, VAR_NAME6) || xtype_in != NC_INT || ndims != 1 || natts != 0 ||
 	  dimids_in[0] != 0) ERR;
       if (nc_inq_var_chunking(ncid, 0, &storage_in, chunksize_in)) ERR;
       if (storage_in != NC_CONTIGUOUS) ERR;
@@ -783,7 +784,7 @@ main(int argc, char **argv)
       if (nvars != 1) ERR;
       if (varids_in[0] != 0) ERR;
       if (nc_inq_var(ncid, 0, name_in, &xtype_in, &ndims, dimids_in, &natts)) ERR;
-      if (strcmp(name_in, VAR_NAME6) || xtype_in != NC_INT || ndims != 1 || natts != 0 || 
+      if (strcmp(name_in, VAR_NAME6) || xtype_in != NC_INT || ndims != 1 || natts != 0 ||
 	  dimids_in[0] != 0) ERR;
       if (nc_inq_var_chunking(ncid, 0, &storage_in, chunksize_in)) ERR;
       if (storage_in != NC_CONTIGUOUS) ERR;
@@ -839,21 +840,21 @@ main(int argc, char **argv)
    SUMMARIZE_ERR;
    printf("**** testing error codes for name clashes...");
    {
-#define GENERIC_NAME "bob"      
+#define GENERIC_NAME "bob"
       int ncid, varid, numgrps, ntypes;
 
       /* Create a netcdf-4 file with one var. */
       if (nc_create(FILE_NAME, NC_NETCDF4, &ncid)) ERR;
       if (nc_def_var(ncid, GENERIC_NAME, NC_BYTE, 0, NULL, &varid)) ERR;
 
-      /* These don'e work, becuase the name is already in use. Make
+      /* These don'e work, because the name is already in use. Make
        * sure the correct error is returned. */
       if (nc_def_grp(ncid, GENERIC_NAME, NULL) != NC_ENAMEINUSE) ERR;
       if (nc_def_opaque(ncid, 1, GENERIC_NAME, NULL) != NC_ENAMEINUSE) ERR;
 
       /* Close it. */
       if (nc_close(ncid)) ERR;
-      
+
       /* Open the file and check. */
       if (nc_open(FILE_NAME, NC_WRITE, &ncid)) ERR;
       if (nc_inq_varids(ncid, &nvars_in, varids_in)) ERR;
@@ -871,21 +872,21 @@ main(int argc, char **argv)
    printf("**** testing error codes for name clashes some more...");
 
    {
-#define GENERIC_NAME "bob"      
+#define GENERIC_NAME "bob"
       int ncid, varid, numgrps, ntypes;
 
       /* Create a netcdf-4 file with one type. */
       if (nc_create(FILE_NAME, NC_NETCDF4, &ncid)) ERR;
       if (nc_def_opaque(ncid, 1, GENERIC_NAME, NULL)) ERR;
 
-      /* These don'e work, becuase the name is already in use. Make
+      /* These don'e work, because the name is already in use. Make
        * sure the correct error is returned. */
       if (nc_def_grp(ncid, GENERIC_NAME, NULL) != NC_ENAMEINUSE) ERR;
       if (nc_def_var(ncid, GENERIC_NAME, NC_BYTE, 0, NULL, &varid) != NC_ENAMEINUSE) ERR;
 
       /* Close it. */
       if (nc_close(ncid)) ERR;
-      
+
       /* Open the file and check. */
       if (nc_open(FILE_NAME, NC_WRITE, &ncid)) ERR;
       if (nc_inq_varids(ncid, &nvars_in, varids_in)) ERR;
@@ -900,21 +901,21 @@ main(int argc, char **argv)
    printf("**** testing error codes for name clashes even more...");
 
    {
-#define GENERIC_NAME "bob"      
+#define GENERIC_NAME "bob"
       int ncid, varid, numgrps, ntypes;
 
       /* Create a netcdf-4 file with one group. */
       if (nc_create(FILE_NAME, NC_NETCDF4, &ncid)) ERR;
       if (nc_def_grp(ncid, GENERIC_NAME, NULL)) ERR;
 
-      /* These don'e work, becuase the name is already in use. Make
+      /* These don'e work, because the name is already in use. Make
        * sure the correct error is returned. */
       if (nc_def_opaque(ncid, 1, GENERIC_NAME, NULL) != NC_ENAMEINUSE) ERR;
       if (nc_def_var(ncid, GENERIC_NAME, NC_BYTE, 0, NULL, &varid) != NC_ENAMEINUSE) ERR;
 
       /* Close it. */
       if (nc_close(ncid)) ERR;
-      
+
       /* Open the file and check. */
       if (nc_open(FILE_NAME, NC_WRITE, &ncid)) ERR;
       if (nc_inq_varids(ncid, &nvars_in, varids_in)) ERR;
@@ -963,7 +964,7 @@ main(int argc, char **argv)
       if (nvars != 1) ERR;
       if (varids_in[0] != 0) ERR;
       if (nc_inq_var(ncid, 0, name_in, &xtype_in, &ndims, dimids_in, &natts)) ERR;
-      if (strcmp(name_in, VAR_NAME17) || xtype_in != NC_UINT64 || ndims != 2 || natts != 0 || 
+      if (strcmp(name_in, VAR_NAME17) || xtype_in != NC_UINT64 || ndims != 2 || natts != 0 ||
 	  dimids_in[0] != 0 || dimids_in[1] != 1) ERR;
       if (nc_inq_var_chunking(ncid, 0, &storage_in, chunksize_in)) ERR;
       for (d = 0; d < NDIMS17; d++)
@@ -982,7 +983,7 @@ main(int argc, char **argv)
       if (nvars != 1) ERR;
       if (varids_in[0] != 0) ERR;
       if (nc_inq_var(ncid, 0, name_in, &xtype_in, &ndims, dimids_in, &natts)) ERR;
-      if (strcmp(name_in, VAR_NAME17) || xtype_in != NC_UINT64 || ndims != 2 || natts != 0 || 
+      if (strcmp(name_in, VAR_NAME17) || xtype_in != NC_UINT64 || ndims != 2 || natts != 0 ||
 	  dimids_in[0] != 0 || dimids_in[1] != 1) ERR;
       if (nc_inq_var_chunking(ncid, 0, &storage_in, chunksize_in)) ERR;
       for (d = 0; d < NDIMS17; d++)
@@ -1018,7 +1019,7 @@ main(int argc, char **argv)
 
       /* This won't work because of the deflate filter. */
       if (nc_def_var_chunking(ncid, varid2, NC_CONTIGUOUS, NULL) != NC_EINVAL) ERR;
-      
+
       /* Storage must be chunked because of unlimited dimension and
        * the deflate filter. */
       if (nc_inq_var_chunking(ncid, varid, &storage_in, chunksize_in)) ERR;
@@ -1056,7 +1057,7 @@ main(int argc, char **argv)
 
       /* This won't work because of the deflate filter. */
       if (nc_def_var_chunking(ncid, varid2, NC_CONTIGUOUS, NULL) != NC_EINVAL) ERR;
-      
+
       /* Storage must be chunked because of unlimited dimension and
        * the deflate filter. */
       if (nc_inq_var_chunking(ncid, varid, &storage_in, chunksize_in)) ERR;
@@ -1069,5 +1070,3 @@ main(int argc, char **argv)
    SUMMARIZE_ERR;
    FINAL_RESULTS;
 }
-
-
