@@ -229,6 +229,14 @@ gen_ncc(const char *filename)
     }
     codeflush();
 
+    /* Set log level */
+    if(ncloglevel >= 0) {
+        codeline("");
+        bbprintf0(stmt,"    nc_set_log_level(%d); /* set log level */",ncloglevel);
+        codedump(stmt);
+        codeline("");
+    }
+
     /* create netCDF file, uses NC_CLOBBER mode */
     codeline("");
     codelined(1,"/* enter define mode */");
@@ -707,7 +715,7 @@ definectype(Symbol* tsym)
 	    Symbol* econst = (Symbol*)listget(tsym->subnodes,i);
 	    Bytebuffer* econststring = bbNew();
 	    ASSERT(econst->subclass == NC_ECONST);
-	    c_generator->constant(c_generator,&econst->typ.econst,econststring);
+	    c_generator->constant(c_generator,tsym,&econst->typ.econst,econststring);
 	    bbNull(econststring);
             /* Enum constants must be converted to a fully qualified name */
 	    bbprintf0(stmt,"#define %s ((%s)%s)\n",
@@ -805,7 +813,7 @@ genc_deftype(Symbol* tsym)
 	    Symbol* econst = (Symbol*)listget(tsym->subnodes,i);
 	    Bytebuffer* econststring = bbNew();
 	    ASSERT(econst->subclass == NC_ECONST);
-	    c_generator->constant(c_generator,&econst->typ.econst,econststring);
+	    c_generator->constant(c_generator,tsym,&econst->typ.econst,econststring);
 	    bbNull(econststring);
 	    bbprintf0(stmt,"%seconst = %s;\n",
 		indented(1),bbContents(econststring));
